=====
Usage
=====

To use pycolombianizer in a project::

    from pycolombianizer.pycolombianizer import Colombianizer
    colombianizer = Colombianizer()
    print(colombianizer.string_2_paisa("hello world"))
    print(colombianizer.string_2_costa("hola mundo"))
